Stan Math Library: stan/math/rev/core/empty_nested.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

empty_nested.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_CORE_EMPTY_NESTED_HPP
2 #define STAN_MATH_REV_CORE_EMPTY_NESTED_HPP
3
4 #include <stan/math/rev/core/chainablestack.hpp>
5
6 namespace stan {
7 namespace math {
8
12 static inline bool empty_nested() {
13 return ChainableStack::nested_var_stack_sizes_.empty();
14 }
15
16
17 }
18 }
19 #endif
stan::math::empty_nested
static bool empty_nested()
Return true if there is no nested autodiff being executed.
Definition: empty_nested.hpp:12
stan
Definition: log_sum_exp.hpp:8
stan::math::AutodiffStackStorage::nested_var_stack_sizes_
static std::vector< size_t > nested_var_stack_sizes_
Definition: autodiffstackstorage.hpp:19
chainablestack.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.